% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.


% Aconitase reaction (EC 4.2.1.3).
% The second reaction in the TCA cycle, which is a two step reaction: 
% dehydration and rehydration.

clear all;

%% Setting up and running Example 1
% (1.) Setting parameter values (no buffering)
B_X   = 0;      % Additional proton buffering capacity
K_BX = 1e-7;    % Dissociation constant of additional proton buffer
par(1) = 0.0001;     % Vmf_ACON
T = 25;             % Temperature

% (2.) Setting initial values
xo(1) = 3e-3;       % Citrate (M)
xo(2) = 5e-4;       % Isocitrate (M)
xo(3) = 1e-7;       % [H] (M)
xo(4) = 1e-3;       % [Mg] (M)
xo(5) = 150e-3;    % [K] (M)

% (3.) Running for 15-second time course
[t,x] = ode15s(@ACON,[0 15],xo,[],T,B_X,K_BX,par);
% (4.) Plotting results
figure(1); p = plot(t,x(:,1)*1e3,'k-',t,x(:,2)*1e3,'k:');
set(p,'linewidth',1.5);
text(1,2.75,'Cirtrate','Fontsize',14);
text(1,0.75,'Isocitrate','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(3); p = plot(t,-log10(x(:,3)),'k-','LineWidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);

Table = array2table([t,x],'variableNames',{'Time','BISEN_Cit','BISEN_IsoCit','BISEN_H','BISEN_Mg','BISEN_K'});
S1 = 'ACONBisenOutput';
S2 = '.csv';
filename1 = strcat(S1);  % Append runtime to filename
filename = strcat(filename1,S2);
%filename = 'ACONBisenOutput.csv';
writetable(Table,filename);
%%
